@@ -119,10 +119,10 @@ def save_sh_stock_uid():
 
 
 # 同步所有互动问题
-def sync_all_interactive_questions(symbol_list):
+def sync_symbols_interactive_questions(symbol_list):
     # 同步互动易映射
-    save_sh_stock_uid()
-
+    if len(symbol_list) == 0:
+        save_sh_stock_uid()
     real_time_quotes_all_stocks = em_stock_info_api.get_a_stock_info()
     de_list_company_symbols = company_common_service_api.get_de_list_company()
     real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[
@@ -149,6 +149,8 @@ def sync_all_interactive_questions(symbol_list):
 
             else:
                 continue
+            if data_frame_util.is_empty(stock_irm_cninfo_df):
+                continue
             stock_irm_cninfo_df['sync_time'] = str_now_date
             stock_irm_cninfo_df['str_day'] = str_day
             stock_irm_cninfo_df.drop_duplicates('_id', keep='last', inplace=True)
@@ -191,6 +193,7 @@ def save_new_data(stock_irm_cninfo_df):
 
 
 if __name__ == '__main__':
+    get_stock_irm_cninfo_sh_api('688778')
     fail_symbol_list_01 = ['000638', '002886', '688778', '688766', '688733', '688778', '688793', '688787']
     # get_stock_irm_cninfo_sh_api('603633')
-    sync_all_interactive_questions(None)
+    sync_symbols_interactive_questions(fail_symbol_list_01)
