@@ -8,7 +8,7 @@ sys.path.append(project_path)
 import mns_common.component.deal.deal_service_api as deal_service_api
 from mns_common.component.deal.terminal_enum import TerminalEnum
 import time
-
+from loguru import logger
 
 # qmt 自动登录
 def qmt_auto_login():
@@ -21,9 +21,11 @@ def ths_auto_login():
 
 
 def auto_login():
-    qmt_auto_login()
-    time.sleep(5)
+    logger.info("打开ths下单程序")
     ths_auto_login()
+    time.sleep(5)
+    logger.info("打开qmt下单程序")
+    qmt_auto_login()
 
 
 if __name__ == '__main__':
