@@ -61,6 +61,7 @@ import mns_scheduler.trade.tfp.stock_tfp_info_sync as stock_tfp_info_sync
 import mns_scheduler.industry.ths.ths_industry_sync_service as ths_industry_sync_service
 import mns_scheduler.k_line.year_quarter.year_quarter_line_sync as year_quarter_line_sync
 import mns_scheduler.k_line.sync_status.k_line_sync_status_check as k_line_sync_status_check
+import mns_scheduler.company_info.base.sync_company_product_area_industry as sync_company_product_area_industry_api
 
 
 # 同步交易日期任务完成
@@ -445,6 +446,11 @@ def check_k_line_sync_count():
     k_line_sync_status_check.check_k_line_sync_count()
 
 
+# 同步公司产品区域信息
+def sync_company_product_area_industry():
+    sync_company_product_area_industry_api.sync_company_product_area_industry()
+
+
 # # 定义BlockingScheduler
 blockingScheduler = BlockingScheduler()
 
@@ -562,6 +568,10 @@ blockingScheduler.add_job(sync_all_kpl_plate_info, 'interval', minutes=5, max_in
 #  check 前复权k线和下一个交易日策略k线数据同步状态
 blockingScheduler.add_job(check_k_line_sync_count, 'cron', hour='0,23', minute='10')
 
+# 同步公司产品区域信息
+blockingScheduler.add_job(sync_company_product_area_industry, 'cron', day_of_week='sat,sun', hour='10,20',
+                          minute='10')
+
 print('定时任务启动成功')
 blockingScheduler.start()
 #
